@@ -37,12 +37,6 @@ GdkPixbuf *eel_create_colorized_pixbuf (GdkPixbuf *src,
 
 char *     rb_utf_friendly_time        (time_t date);
 
-#ifdef HAVE_COLLATE_KEY_FILENAME
-#define rb_utf8_collate_key_for_filename g_utf8_collate_key_for_filename
-#else
-gchar*	rb_utf8_collate_key_for_filename (const gchar *str, gssize len);
-#endif
-
 char *     rb_make_valid_utf8 (const char *name, char substitute);
 
 G_END_DECLS
