@@ -44,11 +44,13 @@ gboolean	rb_uri_is_readable	(const char *uri);
 gboolean	rb_uri_is_writable	(const char *uri);
 gboolean	rb_uri_is_local		(const char *uri);
 gboolean	rb_uri_is_hidden	(const char *uri);
+gboolean	rb_uri_could_be_podcast (const char *uri, gboolean *is_opml);
 char *		rb_uri_make_hidden      (const char *uri);
 char *		rb_uri_get_dir_name	(const char *uri);
 char *		rb_uri_get_short_path_name (const char *uri);
 
-typedef void (*RBUriRecurseFunc) (const char *uri, gboolean dir, gpointer data);
+/* return TRUE to recurse further, FALSE to stop */
+typedef gboolean (*RBUriRecurseFunc) (const char *uri, gboolean dir, gpointer data);
 
 void		rb_uri_handle_recursively(const char *uri,
 					  RBUriRecurseFunc func,
