@@ -60,10 +60,10 @@ extern void rb_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                          gpointer      marshal_data);
 void
 rb_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
-                                             GValue       *return_value,
+                                             GValue       *return_value G_GNUC_UNUSED,
                                              guint         n_param_values,
                                              const GValue *param_values,
-                                             gpointer      invocation_hint,
+                                             gpointer      invocation_hint G_GNUC_UNUSED,
                                              gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN) (gpointer     data1,
@@ -109,10 +109,10 @@ extern void rb_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                          gpointer      marshal_data);
 void
 rb_marshal_BOOLEAN__POINTER (GClosure     *closure,
-                             GValue       *return_value,
+                             GValue       *return_value G_GNUC_UNUSED,
                              guint         n_param_values,
                              const GValue *param_values,
-                             gpointer      invocation_hint,
+                             gpointer      invocation_hint G_GNUC_UNUSED,
                              gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER) (gpointer     data1,
@@ -154,10 +154,10 @@ extern void rb_marshal_BOOLEAN__POINTER_POINTER_POINTER (GClosure     *closure,
                                                          gpointer      marshal_data);
 void
 rb_marshal_BOOLEAN__POINTER_POINTER_POINTER (GClosure     *closure,
-                                             GValue       *return_value,
+                                             GValue       *return_value G_GNUC_UNUSED,
                                              guint         n_param_values,
                                              const GValue *param_values,
-                                             gpointer      invocation_hint,
+                                             gpointer      invocation_hint G_GNUC_UNUSED,
                                              gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER_POINTER_POINTER) (gpointer     data1,
@@ -203,10 +203,10 @@ extern void rb_marshal_BOOLEAN__STRING_STRING_OBJECT (GClosure     *closure,
                                                       gpointer      marshal_data);
 void
 rb_marshal_BOOLEAN__STRING_STRING_OBJECT (GClosure     *closure,
-                                          GValue       *return_value,
+                                          GValue       *return_value G_GNUC_UNUSED,
                                           guint         n_param_values,
                                           const GValue *param_values,
-                                          gpointer      invocation_hint,
+                                          gpointer      invocation_hint G_GNUC_UNUSED,
                                           gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_STRING_OBJECT) (gpointer     data1,
@@ -252,10 +252,10 @@ extern void rb_marshal_INT__VOID (GClosure     *closure,
                                   gpointer      marshal_data);
 void
 rb_marshal_INT__VOID (GClosure     *closure,
-                      GValue       *return_value,
+                      GValue       *return_value G_GNUC_UNUSED,
                       guint         n_param_values,
                       const GValue *param_values,
-                      gpointer      invocation_hint,
+                      gpointer      invocation_hint G_GNUC_UNUSED,
                       gpointer      marshal_data)
 {
   typedef gint (*GMarshalFunc_INT__VOID) (gpointer     data1,
@@ -295,10 +295,10 @@ extern void rb_marshal_OBJECT__OBJECT (GClosure     *closure,
                                        gpointer      marshal_data);
 void
 rb_marshal_OBJECT__OBJECT (GClosure     *closure,
-                           GValue       *return_value,
+                           GValue       *return_value G_GNUC_UNUSED,
                            guint         n_param_values,
                            const GValue *param_values,
-                           gpointer      invocation_hint,
+                           gpointer      invocation_hint G_GNUC_UNUSED,
                            gpointer      marshal_data)
 {
   typedef GObject* (*GMarshalFunc_OBJECT__OBJECT) (gpointer     data1,
@@ -340,10 +340,10 @@ extern void rb_marshal_STRING__STRING (GClosure     *closure,
                                        gpointer      marshal_data);
 void
 rb_marshal_STRING__STRING (GClosure     *closure,
-                           GValue       *return_value,
+                           GValue       *return_value G_GNUC_UNUSED,
                            guint         n_param_values,
                            const GValue *param_values,
-                           gpointer      invocation_hint,
+                           gpointer      invocation_hint G_GNUC_UNUSED,
                            gpointer      marshal_data)
 {
   typedef gchar* (*GMarshalFunc_STRING__STRING) (gpointer     data1,
@@ -385,10 +385,10 @@ extern void rb_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                               gpointer      marshal_data);
 void
 rb_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOOLEAN_BOOLEAN) (gpointer     data1,
@@ -428,10 +428,10 @@ extern void rb_marshal_BOXED__BOXED (GClosure     *closure,
                                      gpointer      marshal_data);
 void
 rb_marshal_BOXED__BOXED (GClosure     *closure,
-                         GValue       *return_value,
+                         GValue       *return_value G_GNUC_UNUSED,
                          guint         n_param_values,
                          const GValue *param_values,
-                         gpointer      invocation_hint,
+                         gpointer      invocation_hint G_GNUC_UNUSED,
                          gpointer      marshal_data)
 {
   typedef gpointer (*GMarshalFunc_BOXED__BOXED) (gpointer     data1,
@@ -473,10 +473,10 @@ extern void rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                           gpointer      marshal_data);
 void
 rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED_BOXED) (gpointer     data1,
@@ -516,10 +516,10 @@ extern void rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
                                                         gpointer      marshal_data);
 void
 rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
-                                            GValue       *return_value,
+                                            GValue       *return_value G_GNUC_UNUSED,
                                             guint         n_param_values,
                                             const GValue *param_values,
-                                            gpointer      invocation_hint,
+                                            gpointer      invocation_hint G_GNUC_UNUSED,
                                             gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED_INT_POINTER_POINTER) (gpointer     data1,
@@ -563,10 +563,10 @@ extern void rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                            gpointer      marshal_data);
 void
 rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED_OBJECT) (gpointer     data1,
@@ -606,10 +606,10 @@ extern void rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                             gpointer      marshal_data);
 void
 rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED_POINTER) (gpointer     data1,
@@ -649,10 +649,10 @@ extern void rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
                                                  gpointer      marshal_data);
 void
 rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
-                                     GValue       *return_value,
+                                     GValue       *return_value G_GNUC_UNUSED,
                                      guint         n_param_values,
                                      const GValue *param_values,
-                                     gpointer      invocation_hint,
+                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED_STRING_BOXED) (gpointer     data1,
@@ -694,10 +694,10 @@ extern void rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
                                           gpointer      marshal_data);
 void
 rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED_ULONG) (gpointer     data1,
@@ -737,10 +737,10 @@ extern void rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
                                           gpointer      marshal_data);
 void
 rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__DOUBLE_LONG) (gpointer     data1,
@@ -780,10 +780,10 @@ extern void rb_marshal_VOID__INT_INT (GClosure     *closure,
                                       gpointer      marshal_data);
 void
 rb_marshal_VOID__INT_INT (GClosure     *closure,
-                          GValue       *return_value,
+                          GValue       *return_value G_GNUC_UNUSED,
                           guint         n_param_values,
                           const GValue *param_values,
-                          gpointer      invocation_hint,
+                          gpointer      invocation_hint G_GNUC_UNUSED,
                           gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
@@ -823,10 +823,10 @@ extern void rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
                                              gpointer      marshal_data);
 void
 rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT_DOUBLE) (gpointer     data1,
@@ -868,10 +868,10 @@ extern void rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                              gpointer      marshal_data);
 void
 rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_INT_INT) (gpointer     data1,
@@ -913,10 +913,10 @@ extern void rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closu
                                                              gpointer      marshal_data);
 void
 rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
-                                                 GValue       *return_value,
+                                                 GValue       *return_value G_GNUC_UNUSED,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
-                                                 gpointer      invocation_hint,
+                                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_INT_INT_BOXED_UINT_UINT) (gpointer     data1,
@@ -964,10 +964,10 @@ extern void rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
                                                  gpointer      marshal_data);
 void
 rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
-                                     GValue       *return_value,
+                                     GValue       *return_value G_GNUC_UNUSED,
                                      guint         n_param_values,
                                      const GValue *param_values,
-                                     gpointer      invocation_hint,
+                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_INT_POINTER) (gpointer     data1,
@@ -1009,10 +1009,10 @@ extern void rb_marshal_VOID__POINTER_INT (GClosure     *closure,
                                           gpointer      marshal_data);
 void
 rb_marshal_VOID__POINTER_INT (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_INT) (gpointer     data1,
@@ -1052,10 +1052,10 @@ extern void rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
                                                   gpointer      marshal_data);
 void
 rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
-                                      GValue       *return_value,
+                                      GValue       *return_value G_GNUC_UNUSED,
                                       guint         n_param_values,
                                       const GValue *param_values,
-                                      gpointer      invocation_hint,
+                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                       gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_INT_POINTER) (gpointer     data1,
@@ -1097,10 +1097,10 @@ extern void rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
                                                 gpointer      marshal_data);
 void
 rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
-                                    GValue       *return_value,
+                                    GValue       *return_value G_GNUC_UNUSED,
                                     guint         n_param_values,
                                     const GValue *param_values,
-                                    gpointer      invocation_hint,
+                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_LONG_LONG) (gpointer     data1,
@@ -1142,10 +1142,10 @@ extern void rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               gpointer      marshal_data);
 void
 rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_POINTER) (gpointer     data1,
@@ -1185,10 +1185,10 @@ extern void rb_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                       gpointer      marshal_data);
 void
 rb_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
-                                          GValue       *return_value,
+                                          GValue       *return_value G_GNUC_UNUSED,
                                           guint         n_param_values,
                                           const GValue *param_values,
-                                          gpointer      invocation_hint,
+                                          gpointer      invocation_hint G_GNUC_UNUSED,
                                           gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_POINTER_POINTER) (gpointer     data1,
@@ -1230,10 +1230,10 @@ extern void rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                            gpointer      marshal_data);
 void
 rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_UINT) (gpointer     data1,
@@ -1273,10 +1273,10 @@ extern void rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
                                             gpointer      marshal_data);
 void
 rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_ULONG) (gpointer     data1,
@@ -1316,10 +1316,10 @@ extern void rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                             gpointer      marshal_data);
 void
 rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_DOUBLE) (gpointer     data1,
@@ -1359,10 +1359,10 @@ extern void rb_marshal_VOID__STRING_INT (GClosure     *closure,
                                          gpointer      marshal_data);
 void
 rb_marshal_VOID__STRING_INT (GClosure     *closure,
-                             GValue       *return_value,
+                             GValue       *return_value G_GNUC_UNUSED,
                              guint         n_param_values,
                              const GValue *param_values,
-                             gpointer      invocation_hint,
+                             gpointer      invocation_hint G_GNUC_UNUSED,
                              gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_INT) (gpointer     data1,
@@ -1402,10 +1402,10 @@ extern void rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                              gpointer      marshal_data);
 void
 rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_POINTER) (gpointer     data1,
@@ -1445,10 +1445,10 @@ extern void rb_marshal_VOID__STRING_STRING (GClosure     *closure,
                                             gpointer      marshal_data);
 void
 rb_marshal_VOID__STRING_STRING (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer     data1,
@@ -1488,10 +1488,10 @@ extern void rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
                                                    gpointer      marshal_data);
 void
 rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
-                                       GValue       *return_value,
+                                       GValue       *return_value G_GNUC_UNUSED,
                                        guint         n_param_values,
                                        const GValue *param_values,
-                                       gpointer      invocation_hint,
+                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                        gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_STRING_OBJECT) (gpointer     data1,
@@ -1533,10 +1533,10 @@ extern void rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                    gpointer      marshal_data);
 void
 rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
-                                       GValue       *return_value,
+                                       GValue       *return_value G_GNUC_UNUSED,
                                        guint         n_param_values,
                                        const GValue *param_values,
-                                       gpointer      invocation_hint,
+                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                        gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING) (gpointer     data1,
@@ -1578,10 +1578,10 @@ extern void rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *cl
                                                                 gpointer      marshal_data);
 void
 rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *closure,
-                                                    GValue       *return_value,
+                                                    GValue       *return_value G_GNUC_UNUSED,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
-                                                    gpointer      invocation_hint,
+                                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_UINT_BOOLEAN) (gpointer     data1,
@@ -1627,10 +1627,10 @@ extern void rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
                                           gpointer      marshal_data);
 void
 rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__ULONG_FLOAT) (gpointer     data1,
@@ -1670,10 +1670,10 @@ extern void rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                              gpointer      marshal_data);
 void
 rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN) (gpointer     data1,
@@ -1713,10 +1713,10 @@ extern void rb_marshal_VOID__STRING_STRING_POINTER_POINTER (GClosure     *closur
                                                             gpointer      marshal_data);
 void
 rb_marshal_VOID__STRING_STRING_POINTER_POINTER (GClosure     *closure,
-                                                GValue       *return_value,
+                                                GValue       *return_value G_GNUC_UNUSED,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
-                                                gpointer      invocation_hint,
+                                                gpointer      invocation_hint G_GNUC_UNUSED,
                                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_STRING_POINTER_POINTER) (gpointer     data1,
