@@ -925,8 +925,8 @@ save_entry (RhythmDBTree *db,
 		case RHYTHMDB_PROP_MUSICBRAINZ_ALBUMARTISTID:
 			save_entry_string(ctx, elt_name, rb_refstring_get (entry->musicbrainz_albumartistid));
 			break;
-		case RHYTHMDB_PROP_MUSICBRAINZ_ARTISTSORTNAME:
-			save_entry_string(ctx, elt_name, rb_refstring_get (entry->musicbrainz_artistsortname));
+		case RHYTHMDB_PROP_ARTIST_SORTNAME:
+			save_entry_string(ctx, elt_name, rb_refstring_get (entry->artist_sortname));
 			break;
 		case RHYTHMDB_PROP_TRACK_NUMBER:
 			save_entry_ulong (ctx, elt_name, entry->tracknum, FALSE);
