@@ -401,29 +401,17 @@ rb_statusbar_sync_status (RBStatusbar *status)
         gboolean show_progress = TRUE;
         char *status_text = NULL;
 	char *progress_text = NULL;
-	float progress = 0.0f;
+	float progress = 999;
 
         /*
          * Behaviour of status bar:
 	 * - use source's status text
 	 * - use source's progress value and text, unless internal progress value is set,
-	 *     or the library is busy
+	 * - if no source progress value or internal progress value and library is busy,
+	 *    pulse the progress bar
          */
-
-	/* get source details */
-        if (status->priv->selected_source)
-		rb_source_get_status (status->priv->selected_source, &status_text, &progress_text, &progress);
-
-        /* internal progress bar moving? */
-        if (status->priv->progress_fraction < (1.0 - EPSILON) || status->priv->progress_changed) {
-		progress = status->priv->progress_fraction;
-                progress_text = g_strdup (status->priv->progress_text);
-                status->priv->progress_changed = FALSE;
-		show_progress = TRUE;
-		changed = TRUE;
-        }
-
-        /* library busy? */
+        
+	/* library busy? */
         if (rhythmdb_is_busy (status->priv->db)) {
 		/*g_free (status_text);
 		status_text = g_strdup (status->priv->loading_text); */
@@ -431,6 +419,24 @@ rb_statusbar_sync_status (RBStatusbar *status)
 		changed = TRUE;
         }
 
+	/* get source details */
+        if (status->priv->selected_source) {
+		rb_source_get_status (status->priv->selected_source, &status_text, &progress_text, &progress);
+		rb_debug ("updating status with: '%s', '%s', %f",
+			status_text ? status_text : "", progress_text ? progress_text : "", progress);
+	}
+
+        /* internal progress bar moving? */
+        if (status->priv->progress_fraction < (1.0 - EPSILON) || status->priv->progress_changed) {
+		g_free (progress_text);
+                progress_text = g_strdup (status->priv->progress_text);
+		progress = status->priv->progress_fraction;
+
+                status->priv->progress_changed = FALSE;
+		show_progress = TRUE;
+		changed = TRUE;
+        }
+
         /* set up the status text */
         if (status_text) {
                 gtk_statusbar_pop (GTK_STATUSBAR (status), 0);
@@ -439,7 +445,7 @@ rb_statusbar_sync_status (RBStatusbar *status)
         }
 
         /* set up the progress bar */
-	if (progress > (1.0f - EPSILON) && !show_progress) {
+	if (progress > (1.0f - EPSILON) || !show_progress) {
 		gtk_widget_hide (status->priv->progress);
 	} else {
                 gtk_widget_show (status->priv->progress);
